@@ -26,4 +26,17 @@ def programming_joke():
 def random_joke():
     url = "https://v2.jokeapi.dev/joke/Any?blacklistFlags=nsfw,religious,political,racist,sexist,explicit&format=txt"
     response = requests.request("GET", url)
-    print(response.text)
\ No newline at end of file
+    print(response.text)
+
+def JOD():
+    print("https://v2.jokeapi.dev/joke/Any?blacklistFlags=nsfw,religious,political,racist,sexist,explicit&format=txt")
+
+def Multiple_Jokes(n):
+    for i in range(n):
+        url = "https://icanhazdadjoke.com/"
+        html_content = requests.get(url).text
+        soup = BeautifulSoup(html_content, "html.parser")
+        print(soup.find('p').text)
+
+def version():
+    print("0.0.3")
\ No newline at end of file
